@@ -8,7 +8,7 @@ Log::Fine::Handle::Console - Output messages to C<STDERR> or C<STDOUT>
 Provides logging to either C<STDERR> or C<STDOUT>.
 
     # Get a new logger
-    my $log = Log::Fine->getLogger("foo");
+    my $log = Log::Fine->logger("foo");
 
     # register a file handle
     my $handle = Log::Fine::Handle::Console
@@ -41,9 +41,9 @@ use base qw( Log::Fine::Handle );
 
 =head1 METHODS
 
-=head2 msgWrite($lvl, $msg, $skip)
+=head2 msgWrite
 
-See L<Log::Fine::Handle>
+See L<Log::Fine::Handle/msgWrite>
 
 =cut
 
@@ -140,11 +140,11 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 REVISION INFORMATION
 
-  $Id: Console.pm 76 2008-06-06 16:36:28Z cfuhrman $
+  $Id: Console.pm 200 2010-01-03 20:20:44Z cfuhrman $
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (c) 2008 Christopher M. Fuhrman, 
+Copyright (c) 2008, 2010 Christopher M. Fuhrman, 
 All rights reserved.
 
 This program is free software licensed under the...
