@@ -74,20 +74,6 @@ The following methods are provided:
 
 Creates a new Log::Fine::Levels object
 
-=head3 Parameters
-
-=over
-
-=item  * levelmap
-
-The name of the level map to use (e.g., C<Syslog>, C<Java>, etc)
-
-=back
-
-=head3 Returns
-
-an L<Log::Fine::Levels> object
-
 =cut
 
 sub new
@@ -100,7 +86,7 @@ sub new
         my $levelClass = join("::", $class, $lvlmap);
 
         # validate levelclass
-        eval "require $levelClass";
+        eval "require $levelClass;";
 
         # Do we have the class defined?
         confess "Error : Level Class $levelClass does not exist : $@"
@@ -327,7 +313,7 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 REVISION INFORMATION
 
-  $Id: 43f9332c0fbf25f4f779945812b69466968262df $
+  $Id: Levels.pm 200 2010-01-03 20:20:44Z cfuhrman $
 
 =head1 COPYRIGHT & LICENSE
 
